import {Component, inject} from "@angular/core";
import {HotelComponent} from "./hotel.component";
import {Hotel} from "./hotel";
import {FormsModule} from "@angular/forms";
import {Lang} from "../idek/lang";
import {HotelService} from "../service/hotel.service";

@Component({
  standalone: true,
  template: `
    <select [ngModel]="currency" (ngModelChange)="setCurrency($event)">
      @for (currency of currencies; track null) {
        <option value="{{currency.name}}">{{currency.name}}</option>
      }
    </select>
    <form>
      <input name="search" [ngModel]="search" (ngModelChange)="searchEvent($event)">
    </form>
    @for (hotel of matchingHotels; track hotel.hotelId) {
        <app-hotel [hotel]="hotel" [currency]="currency"></app-hotel>
        <hr>
    } @empty {
      <h1>no matching results for {{search}}</h1>
    }
  `,
  imports: [FormsModule, HotelComponent],
  providers: [HotelService],
  selector: 'app-hotels'
})
export class HotelsComponent {
  public search: string = '';

  public currency: Lang = {name: 'de', code: 'de-DE', currency: 'EUR'};

  public currencies: Lang[] = [
    {
      name: 'de',
      code: 'de-DE',
      currency: 'EUR'
    },
    {
      name: 'en',
      code: 'en-US',
      currency: 'USD'
    },
    {
      name: 'jap',
      code: 'ja-JP',
      currency: 'JPY'
    },
    {
      name: 'cn',
      code: 'cn-CN',
      currency: 'CNY'
    }
  ]

  public matchingHotels: Hotel[] = [];

  private hotelService: HotelService = inject(HotelService);

  constructor() {
    this.matchingHotels = this.hotelService.getHotels;
  }

  public setCurrency(currencyInput: string): void {
    for (const currency of this.currencies) {
      if (currency.name === currencyInput) {
        this.currency = currency;
        break;
      }
    }
  }

  public searchEvent(input: string) {
    this.search = input.toLowerCase();
    this.matchingHotels = []
    this.hotelService.getHotels .forEach((hotel: Hotel) => {
      if (hotel.hotelName.toLowerCase().includes(this.search)) {
          this.matchingHotels.push(hotel);
      }
    })
  }
}
